#ifndef NT2_INCLUDE_FUNCTIONS_I0_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_I0_HPP_INCLUDED

#include <nt2/bessel/include/functions/i0.hpp>

#endif
